summaryrefslogtreecommitdiff
path: root/clients
diff options
context:
space:
mode:
authorGravatar Robert S. French <rfrench@mit.edu>1987-10-24 21:21:56 +0000
committerGravatar Robert S. French <rfrench@mit.edu>1987-10-24 21:21:56 +0000
commit3f38347f8ebeadfedc9449fc7dad6ac30acb91b5 (patch)
tree306fef2bbdd17d9cc8209cd5e5e027230810d62e /clients
parent03db54b3e83c126ec4912e1827c20422a3ddc455 (diff)
zwmnotify -> zmailnotify
Diffstat (limited to 'clients')
-rw-r--r--clients/zmailnotify/zmailnotify.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/clients/zmailnotify/zmailnotify.c b/clients/zmailnotify/zmailnotify.c
index 445ab2d..8d86728 100644
--- a/clients/zmailnotify/zmailnotify.c
+++ b/clients/zmailnotify/zmailnotify.c
@@ -1,5 +1,5 @@
/* This file is part of the Project Athena Zephyr Notification System.
* It contains code for the "zwmnotify" command.
*
* Created by: Robert French
*
@@ -50,7 +50,7 @@ char Errmsg[80];
char *PrincipalHostname(), *index();
#endif KPOP
-#define MAXMAIL 8
+#define MAXMAIL 4
struct _mail {
char *from;
@@ -76,7 +76,7 @@ main()
#endif HESIOD
if ((retval = ZInitialize()) != ZERR_NONE) {
- com_err("zwmnotify",retval,"while initializing");
+ com_err("zmailnotify",retval,"while initializing");
exit(1);
}
@@ -311,7 +311,7 @@ mail_notify(mail)
fields[2] = mail->subj;
if ((retval = ZSendList(&notice,fields,3,ZNOAUTH)) != ZERR_NONE)
- com_err("zwmnotify",retval,"while sending notice");
+ com_err("zmailnotify",retval,"while sending notice");
}
/*
@@ -1,5 +1,5 @@
/* This file is part of the Project Athena Zephyr Notification System.
- * It contains code for the "zwmnotify" command.
+ * It contains code for the "zmailnotify" command.
*
* Created by: Robert French